package ru.dbotthepony.mc.otm.menu.decorative

import net.minecraft.world.entity.player.Inventory
import ru.dbotthepony.mc.otm.block.entity.RedstoneSetting
import ru.dbotthepony.mc.otm.block.entity.decorative.HoloSignBlockEntity
import ru.dbotthepony.mc.otm.menu.MatteryMenu
import ru.dbotthepony.mc.otm.menu.input.BooleanInputWithFeedback
import ru.dbotthepony.mc.otm.menu.input.EnumInputWithFeedback
import ru.dbotthepony.mc.otm.menu.input.FloatInputWithFeedback
import ru.dbotthepony.mc.otm.menu.input.StringInputWithFeedback
import ru.dbotthepony.mc.otm.registry.game.MMenus

class HoloSignMenu(
	containerId: Int,
	inventory: Inventory,
	tile: HoloSignBlockEntity? = null
) : MatteryMenu(MMenus.HOLO_SIGN, containerId, inventory, tile) {
	val text = StringInputWithFeedback(this)
	val locked = BooleanInputWithFeedback(this)
	val redstone = EnumInputWithFeedback(this, RedstoneSetting::class.java)

	val textRed = FloatInputWithFeedback(this)
	val textGreen = FloatInputWithFeedback(this)
	val textBlue = FloatInputWithFeedback(this)
	val textAlpha = FloatInputWithFeedback(this)
	val textAutoScale = BooleanInputWithFeedback(this)

	init {
		text.filter { it.isCreative || !locked.value }
		redstone.filter { it.isCreative || !locked.value }
		locked.filter { it.isCreative }

		textRed.filter { it.isCreative || !locked.value }
		textGreen.filter { it.isCreative || !locked.value }
		textBlue.filter { it.isCreative || !locked.value }
		textAlpha.filter { it.isCreative || !locked.value }

		textAutoScale.filter { it.isCreative || !locked.value }

		if (tile != null) {
			text.withConsumer { tile.signText = HoloSignBlockEntity.truncate(it, tile.isLocked) }.withSupplier(tile::signText)
			textRed.withConsumer { tile.textRed = it.coerceIn(0f, 1f) }.withSupplier(tile::textRed)
			textGreen.withConsumer { tile.textGreen = it.coerceIn(0f, 1f) }.withSupplier(tile::textGreen)
			textBlue.withConsumer { tile.textBlue = it.coerceIn(0f, 1f) }.withSupplier(tile::textBlue)
			textAlpha.withConsumer { tile.textAlpha = it.coerceIn(0f, 1f) }.withSupplier(tile::textAlpha)
			locked.with(tile::isLocked)
			redstone.with(tile.redstoneControl::redstoneSetting)
			textAutoScale.with(tile::textAutoScale)
		}
	}
}
